=========
clinepunk
=========


.. image:: https://img.shields.io/pypi/v/clinepunk.svg
        :target: https://pypi.python.org/pypi/clinepunk

.. image:: https://img.shields.io/travis/TaylorMonacelli/clinepunk.svg
        :target: https://travis-ci.com/TaylorMonacelli/clinepunk

.. image:: https://readthedocs.org/projects/clinepunk/badge/?version=latest
        :target: https://clinepunk.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/TaylorMonacelli/clinepunk/shield.svg
     :target: https://pyup.io/repos/github/TaylorMonacelli/clinepunk/
     :alt: Updates



Python Boilerplate contains all the boilerplate you need to create a Python package.


* Free software: MIT license
* Documentation: https://clinepunk.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
